/*************************
 * Check and Radio items *
 *************************/

/* draw regular check and radio items using our SVG assets */
.check,
.check row:selected,
.check row:selected:focused {
    background-image: url("assets/checkbox-unchecked-dark.svg");
}

.check:insensitive,
.check row:selected:insensitive,
.check row:selected:focused:insensitive {
    background-image: url("assets/checkbox-unchecked-insensitive-dark.svg");
}

.check:active,
.check row:selected:active,
.check row:selected:focused:active {
    background-image: url("assets/checkbox-checked-dark.svg");
}

.check:active:insensitive,
.check row:selected:active:insensitive,
.check row:selected:focused:active:insensitive
{
    background-image: url("assets/checkbox-checked-insensitive-dark.svg");
}

.check:inconsistent,
.check row:selected:inconsistent,
.check row:selected:focused:inconsistent {
    background-image: url("assets/checkbox-mixed-dark.svg");
}

.check:inconsistent:insensitive,
.check row:selected:inconsistent:insensitive,
.check row:selected:focused:inconsistent:insensitive {
    background-image: url("assets/checkbox-mixed-insensitive-dark.svg");
}

.radio,
.radio row:selected,
.radio row:selected:focused {
    background-image: url("assets/radio-unselected-dark.svg");
}

.radio:insensitive,
.radio row:selected:insensitive,
.radio row:selected:focused:insensitive {
    background-image: url("assets/radio-unselected-insensitive-dark.svg");
}

.radio:active,
.radio row:selected:active,
.radio row:selected:focused:active {
    background-image: url("assets/radio-selected-dark.svg");
}

.radio:active:insensitive,
.radio row:selected:active:insensitive,
.radio row:selected:focused:active:insensitive {
    background-image: url("assets/radio-selected-insensitive-dark.svg");
}

.radio:inconsistent,
.radio row:selected:inconsistent,
.radio row:selected:focused:inconsistent {
    background-image: url("assets/radio-mixed-dark.svg");
}

.radio:inconsistent:insensitive,
.radio row:selected:inconsistent:insensitive,
.radio row:selected:focused:inconsistent:insensitive {
    background-image: url("assets/radio-mixed-insensitive-dark.svg");
}

.sidebar .radio:active,
.sidebar .radio:active:focused,
.sidebar .radio:active:prelight {
    background-image: url("assets/sidebar-radio-checked-dark.svg");
}

.sidebar .radio:prelight {
    background-image: url("assets/sidebar-radio-prelight.svg");
}

.sidebar .radio:active:selected,
.sidebar .radio:active:selected:focused {
    background-image: url("assets/sidebar-radio-selected-dark.svg");
}

.sidebar .radio:selected:prelight,
.sidebar .radio:selected:focused {
    background-image: url("assets/sidebar-radio-selected-prelight.svg");    
}

GtkScale.slider,
GtkScale.slider.horizontal {
    background-image: url("assets/scale-slider-horizontal-dark.svg");
}

GtkScale.slider:insensitive,
GtkScale.slider.horizontal:insensitive {
    background-image: url("assets/scale-slider-horizontal-insensitive-dark.svg");
}

GtkScale.slider.vertical {
    background-image: url("assets/scale-slider-vertical-dark.svg");
}

GtkScale.slider.vertical:insensitive {
    background-image: url("assets/scale-slider-vertical-insensitive-dark.svg");
}

GtkScale.scale-has-marks-above.slider.horizontal {
    background-image: url("assets/scale-slider-marks-above-horizontal-dark.svg");
}

GtkScale.scale-has-marks-above.slider.horizontal:insensitive {
    background-image: url("assets/scale-slider-marks-above-horizontal-insensitive-dark.svg");
}

GtkScale.scale-has-marks-above.slider.vertical {
    background-image: url("assets/scale-slider-marks-above-vertical-dark.svg");
}

GtkScale.scale-has-marks-above.slider.vertical:insensitive {
    background-image: url("assets/scale-slider-marks-above-vertical-insensitive-dark.svg");
}

GtkScale.scale-has-marks-below.slider.horizontal {
    background-image: url("assets/scale-slider-marks-below-horizontal-dark.svg");
}

GtkScale.scale-has-marks-below.slider.horizontal:insensitive {
    background-image: url("assets/scale-slider-marks-below-horizontal-insensitive-dark.svg");
}

GtkScale.scale-has-marks-below.slider.vertical {
    background-image: url("assets/scale-slider-marks-below-vertical-dark.svg");
}

GtkScale.scale-has-marks-below.slider.vertical:insensitive {
    background-image: url("assets/scale-slider-marks-below-vertical-insensitive-dark.svg");
}


